@@ -137,21 +137,23 @@ def main():
         sys.exit('Profile not found')
 
     cache_key = generate_cache_key(**profile_details)
+    cache_data = None
     try:
         cache_data = read_cache_json(cache_key)
     except Exception:
-        #sys.exit(f'Unable to read cache file generated by aws cli. Try running aws configure sso --profile {profile_name}')
         print(f'AWSHELPER: Credentials file not found. Executing aws sts get-caller-identity --profile {profile_name} to generate it')
         call_sts_get_caller_identity(profile_name)
 
-    try:
-        cache_data = read_cache_json(cache_key)
-    except Exception:
-        sys.exit(f'AWSHELPER: Unable to read cache file generated by aws cli. You might not be logged in (run aws configure sso --profile {profile_name}')
+    if not cache_data:
+        try:
+            cache_data = read_cache_json(cache_key)
+        except Exception:
+            sys.exit(f'AWSHELPER: Unable to read cache file generated by aws cli. You might not be logged in (run aws configure sso --profile {profile_name}')
 
     if check_cache_expiry(cache_data['Credentials']['Expiration']):
         print(f'AWSHELPER: Credentials cache has expired. Executing Executing aws sts get-caller-identity --profile {profile_name} to attempt to refresh it')
         call_sts_get_caller_identity(profile_name)
+        cache_data = read_cache_json(cache_key)
 
     if is_external_process_mode():
         print(json.dumps(generate_process_cred_json(cache_data), indent=4, sort_keys=True))
